@@ -1,5 +1,8 @@
+import base64
+import codecs
 import itertools
 import re
+import string
 
 from .common import InfoExtractor
 from ..utils import (
@@ -10,15 +13,88 @@ from ..utils import (
     extract_attributes,
     float_or_none,
     int_or_none,
+    join_nonempty,
     parse_duration,
     str_or_none,
+    try_call,
     try_get,
     unified_strdate,
     url_or_none,
-    urljoin,
 )
 
 
+def to_signed_32(n):
+    return n % ((-1 if n < 0 else 1) * 2**32)
+
+
+class _ByteGenerator:
+    def __init__(self, algo_id, seed):
+        try:
+            self._algorithm = getattr(self, f'_algo{algo_id}')
+        except AttributeError:
+            raise ExtractorError(f'Unknown algorithm ID: {algo_id}')
+        self._s = to_signed_32(seed)
+
+    def _algo1(self, s):
+        # LCG (a=1664525, c=1013904223, m=2^32)
+        # Ref: https://en.wikipedia.org/wiki/Linear_congruential_generator
+        s = self._s = to_signed_32(s * 1664525 + 1013904223)
+        return s
+
+    def _algo2(self, s):
+        # xorshift32
+        # Ref: https://en.wikipedia.org/wiki/Xorshift
+        s = to_signed_32(s ^ (s << 13))
+        s = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 17))
+        s = self._s = to_signed_32(s ^ (s << 5))
+        return s
+
+    def _algo3(self, s):
+        # Weyl Sequence (k≈2^32*φ, m=2^32) + MurmurHash3 (fmix32)
+        # Ref: https://en.wikipedia.org/wiki/Weyl_sequence
+        # https://commons.apache.org/proper/commons-codec/jacoco/org.apache.commons.codec.digest/MurmurHash3.java.html
+        s = self._s = to_signed_32(s + 0x9e3779b9)
+        s = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 16))
+        s = to_signed_32(s * to_signed_32(0x85ebca77))
+        s = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 13))
+        s = to_signed_32(s * to_signed_32(0xc2b2ae3d))
+        return to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 16))
+
+    def _algo4(self, s):
+        # Custom scrambling function involving a left rotation (ROL)
+        s = self._s = to_signed_32(s + 0x6d2b79f5)
+        s = to_signed_32((s << 7) | ((s & 0xFFFFFFFF) >> 25))  # ROL 7
+        s = to_signed_32(s + 0x9e3779b9)
+        s = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 11))
+        return to_signed_32(s * 0x27d4eb2d)
+
+    def _algo5(self, s):
+        # xorshift variant with a final addition
+        s = to_signed_32(s ^ (s << 7))
+        s = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 9))
+        s = to_signed_32(s ^ (s << 8))
+        s = self._s = to_signed_32(s + 0xa5a5a5a5)
+        return s
+
+    def _algo6(self, s):
+        # LCG (a=0x2c9277b5, c=0xac564b05) with a variable right shift scrambler
+        s = self._s = to_signed_32(s * to_signed_32(0x2c9277b5) + to_signed_32(0xac564b05))
+        s2 = to_signed_32(s ^ ((s & 0xFFFFFFFF) >> 18))
+        shift = (s & 0xFFFFFFFF) >> 27 & 31
+        return to_signed_32((s2 & 0xFFFFFFFF) >> shift)
+
+    def _algo7(self, s):
+        # Weyl Sequence (k=0x9e3779b9) + custom multiply-xor-shift mixing function
+        s = self._s = to_signed_32(s + to_signed_32(0x9e3779b9))
+        e = to_signed_32(s ^ (s << 5))
+        e = to_signed_32(e * to_signed_32(0x7feb352d))
+        e = to_signed_32(e ^ ((e & 0xFFFFFFFF) >> 15))
+        return to_signed_32(e * to_signed_32(0x846ca68b))
+
+    def __next__(self):
+        return self._algorithm(self._s) & 0xFF
+
+
 class XHamsterIE(InfoExtractor):
     _DOMAINS = r'(?:xhamster\.(?:com|one|desi)|xhms\.pro|xhamster\d+\.(?:com|desi)|xhday\.com|xhvid\.com)'
     _VALID_URL = rf'''(?x)
@@ -140,6 +216,43 @@ class XHamsterIE(InfoExtractor):
         'only_matching': True,
     }]
 
+    _XOR_KEY = b'xh7999'
+
+    def _decipher_format_url(self, format_url, format_id):
+        if all(char in string.hexdigits for char in format_url):
+            byte_data = bytes.fromhex(format_url)
+            seed = int.from_bytes(byte_data[1:5], byteorder='little', signed=True)
+            byte_gen = _ByteGenerator(byte_data[0], seed)
+            return bytearray(byte ^ next(byte_gen) for byte in byte_data[5:]).decode('latin-1')
+
+        cipher_type, _, ciphertext = try_call(
+            lambda: base64.b64decode(format_url).decode().partition('_')) or [None] * 3
+
+        if not cipher_type or not ciphertext:
+            self.report_warning(f'Skipping format "{format_id}": failed to decipher URL')
+            return None
+
+        if cipher_type == 'xor':
+            return bytes(
+                a ^ b for a, b in
+                zip(ciphertext.encode(), itertools.cycle(self._XOR_KEY))).decode()
+
+        if cipher_type == 'rot13':
+            return codecs.decode(ciphertext, cipher_type)
+
+        self.report_warning(f'Skipping format "{format_id}": unsupported cipher type "{cipher_type}"')
+        return None
+
+    def _fixup_formats(self, formats):
+        for f in formats:
+            if f.get('vcodec'):
+                continue
+            for vcodec in ('av1', 'h264'):
+                if any(f'.{vcodec}.' in f_url for f_url in (f['url'], f.get('manifest_url', ''))):
+                    f['vcodec'] = vcodec
+                    break
+        return formats
+
     def _real_extract(self, url):
         mobj = self._match_valid_url(url)
         video_id = mobj.group('id') or mobj.group('id_2')
@@ -210,7 +323,7 @@ class XHamsterIE(InfoExtractor):
                         hls_url = hls_sources.get(hls_format_key)
                         if not hls_url:
                             continue
-                        hls_url = urljoin(url, hls_url)
+                        hls_url = self._decipher_format_url(hls_url, f'hls-{hls_format_key}')
                         if not hls_url or hls_url in format_urls:
                             continue
                         format_urls.add(hls_url)
@@ -219,7 +332,7 @@ class XHamsterIE(InfoExtractor):
                             m3u8_id='hls', fatal=False))
                 standard_sources = xplayer_sources.get('standard')
                 if isinstance(standard_sources, dict):
-                    for format_id, formats_list in standard_sources.items():
+                    for identifier, formats_list in standard_sources.items():
                         if not isinstance(formats_list, list):
                             continue
                         for standard_format in formats_list:
@@ -229,7 +342,11 @@ class XHamsterIE(InfoExtractor):
                                 standard_url = standard_format.get(standard_format_key)
                                 if not standard_url:
                                     continue
-                                standard_url = urljoin(url, standard_url)
+                                quality = (str_or_none(standard_format.get('quality'))
+                                           or str_or_none(standard_format.get('label'))
+                                           or '')
+                                format_id = join_nonempty(identifier, quality)
+                                standard_url = self._decipher_format_url(standard_url, format_id)
                                 if not standard_url or standard_url in format_urls:
                                     continue
                                 format_urls.add(standard_url)
@@ -239,11 +356,9 @@ class XHamsterIE(InfoExtractor):
                                         standard_url, video_id, 'mp4', entry_protocol='m3u8_native',
                                         m3u8_id='hls', fatal=False))
                                     continue
-                                quality = (str_or_none(standard_format.get('quality'))
-                                           or str_or_none(standard_format.get('label'))
-                                           or '')
+
                                 formats.append({
-                                    'format_id': f'{format_id}-{quality}',
+                                    'format_id': format_id,
                                     'url': standard_url,
                                     'ext': ext,
                                     'height': get_height(quality),
@@ -286,7 +401,8 @@ class XHamsterIE(InfoExtractor):
                 'comment_count': int_or_none(video.get('comments')),
                 'age_limit': age_limit if age_limit is not None else 18,
                 'categories': categories,
-                'formats': formats,
+                'formats': self._fixup_formats(formats),
+                '_format_sort_fields': ('res', 'proto', 'tbr'),
             }
 
         # Old layout fallback
